.. _linear_elasticity-linear_elastic_interactive:

linear_elasticity/linear_elastic_interactive.py
===============================================

**Description**


Linear elasticity example using the imperative API.


.. image:: /../doc/images/gallery/linear_elasticity-linear_elastic_interactive.png


:download:`source code </../sfepy/examples/linear_elasticity/linear_elastic_interactive.py>`

.. literalinclude:: /../sfepy/examples/linear_elasticity/linear_elastic_interactive.py

